.. cauliflow documentation master file, created by
   sphinx-quickstart on Mon May 19 15:31:15 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

CauliFlow
=======================

CauliFlow is a simple workflow tool.
CauliFlow allows you to construct and run workflows by connecting multiple nodes in a YAML-format file.
CauliFlow enables the creation of flexible, reusable workflows by utilising three types of variable: Flowdata, Blackboard and Macros.
Although CauliFlow is primarily designed to work with EPICS PVs, it can also be used for other purposes.

.. caution::
    CauliFlow is currently under active development.
    Its features, specifications, and APIs are subject to change without prior notice.

Links
-----
* `Source(GitHub) <https://github.com/sasaki77/cauliflow>`_

Documentation
-------------
.. toctree::
   :maxdepth: 2

   installation
   introduction
   overview/index
   tutorials/index
   nodes/index
   filters
